.. include:: ../README.rst

Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self

.. toctree::
    :caption: Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 3

    api

.. toctree::
    :caption: Tutorials

    CircuitPython displayio Setup for TFT FeatherWings <https://learn.adafruit.com/using-circuitpython-displayio-with-a-tft-featherwing>

.. toctree::
    :caption: Development
    :maxdepth: 3

    developing

.. toctree::
    :caption: Related Products

    Adafruit Feather M4 Express - Featuring ATSAMD51 - ATSAMD51 Cortex M4<https://www.adafruit.com/product/3857>
    Adafruit TFT FeatherWing - 3.5" 480x320 Touchscreen for Feathers <https://www.adafruit.com/product/3651>
    TFT FeatherWing - 2.4" 320x240 Touchscreen For All Feathers <https://www.adafruit.com/product/3315>
    Adafruit Mini Color TFT with Joystick FeatherWing <https://www.adafruit.com/product/3321>

.. toctree::
    :caption: Other Links

    Download from GitHub <https://github.com/adafruit/Adafruit_CircuitPython_ImageLoad/releases/latest>
    Download Library Bundle <https://circuitpython.org/libraries>
    CircuitPython Reference Documentation <https://docs.circuitpython.org>
    CircuitPython Support Forum <https://forums.adafruit.com/viewforum.php?f=60>
    Discord Chat <https://adafru.it/discord>
    Adafruit Learning System <https://learn.adafruit.com>
    Adafruit Blog <https://blog.adafruit.com>
    Adafruit Store <https://www.adafruit.com>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
